@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -60,6 +60,7 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
   public static final String ANNOTATION_CHE_USERID = "che.eclipse.org/che-userid";
   public static final String ANNOTATION_SCM_USERID = "che.eclipse.org/scm-userid";
   public static final String ANNOTATION_SCM_USERNAME = "che.eclipse.org/scm-username";
+  public static final String ANNOTATION_SCM_ORGANIZATION = "che.eclipse.org/scm-organization";
   public static final String ANNOTATION_SCM_PERSONAL_ACCESS_TOKEN_ID =
       "che.eclipse.org/scm-personal-access-token-id";
   public static final String ANNOTATION_SCM_PERSONAL_ACCESS_TOKEN_NAME =
@@ -156,6 +157,7 @@ public class KubernetesPersonalAccessTokenManager implements PersonalAccessToken
                 new PersonalAccessToken(
                     trimmedUrl,
                     annotations.get(ANNOTATION_CHE_USERID),
+                    annotations.get(ANNOTATION_SCM_ORGANIZATION),
                     annotations.get(ANNOTATION_SCM_USERNAME),
                     annotations.get(ANNOTATION_SCM_USERID),
                     annotations.get(ANNOTATION_SCM_PERSONAL_ACCESS_TOKEN_NAME),
