@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -56,7 +56,7 @@ public class GithubPersonalAccessTokenFetcher implements PersonalAccessTokenFetc
 
   /** Collection of OAuth scopes required to make integration with GitHub work. */
   public static final Set<String> DEFAULT_TOKEN_SCOPES =
-      ImmutableSet.of("repo", "user:email", "read:user", "workflow");
+      ImmutableSet.of("repo", "user:email", "read:user", "read:org", "workflow");
 
   /**
    * Map of OAuth GitHub scopes where each key is a scope and its value is the parent scope. The
